Stan Math Library: stan/math/fwd/scal/meta/is_fvar.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

is_fvar.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_META_IS_FVAR_HPP
2 #define STAN_MATH_FWD_SCAL_META_IS_FVAR_HPP
3
4 #include <stan/math/fwd/core.hpp>
5 #include <stan/math/prim/scal/meta/is_fvar.hpp>
6
7 namespace stan {
8
9 template <typename T>
10 struct is_fvar<stan::math::fvar<T> > {
11 enum { value = true };
12 };
13
14 }
15 #endif
stan::is_fvar::value
Definition: is_fvar.hpp:8
core.hpp
stan
Definition: log_sum_exp.hpp:8
is_fvar.hpp
stan::is_fvar
Definition: is_fvar.hpp:7
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.